sqlobject.tests.test_lazy module — SQLObject 3.9.1 documentation

# sqlobject.tests.test_lazy module

class `sqlobject.tests.test_lazy.` `Lazy`(**kw)

  Bases: `sqlobject.main.SQLObject`

  `j` = lazy
  property `name`
  property `other`
  `q` = lazy
  class `sqlmeta`(instance)

    Bases: `sqlobject.main.sqlmeta`

    `childName` = None
    `idName` = 'id'
    `indexes` = []
    `joinDefinitions` = []
    `joins` = []
    `lazyUpdate` = True
    `soClass`

      alias of `sqlobject.tests.test_lazy.Lazy`

    `style` = <sqlobject.styles.MixedCaseUnderscoreStyle object>
    `table` = 'lazy'
  property `third`

class `sqlobject.tests.test_lazy.` `TestLazyTest`

  Bases: `object`

  `setup_method`(meth)
  `teardown_method`(meth)
  `test_lazy`()